import OCP.IntSurf
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.gp
import OCP.Standard
import OCP.GeomAbs
import OCP.NCollection
import OCP.Adaptor3d
__all__  = [
"IntSurf",
"IntSurf_Couple",
"IntSurf_InteriorPoint",
"IntSurf_InteriorPointTool",
"IntSurf_LineOn2S",
"IntSurf_ListOfPntOn2S",
"IntSurf_PathPoint",
"IntSurf_PathPointTool",
"IntSurf_PntOn2S",
"IntSurf_Quadric",
"IntSurf_QuadricTool",
"IntSurf_SequenceOfCouple",
"IntSurf_SequenceOfInteriorPoint",
"IntSurf_SequenceOfPathPoint",
"IntSurf_SequenceOfPntOn2S",
"IntSurf_Situation",
"IntSurf_Transition",
"IntSurf_TypeTrans",
"IntSurf_In",
"IntSurf_Inside",
"IntSurf_Out",
"IntSurf_Outside",
"IntSurf_Touch",
"IntSurf_Undecided",
"IntSurf_Unknown"
]
class IntSurf():
    """
    This package provides resources for all the packages concerning the intersection between surfaces.
    """
    @staticmethod
    def MakeTransition_s(TgFirst : OCP.gp.gp_Vec,TgSecond : OCP.gp.gp_Vec,Normal : OCP.gp.gp_Dir,TFirst : IntSurf_Transition,TSecond : IntSurf_Transition) -> None: 
        """
        Computes the transition of the intersection point between the two lines. TgFirst is the tangent vector of the first line. TgSecond is the tangent vector of the second line. Normal is the direction used to orientate the cross product TgFirst^TgSecond. TFirst is the transition of the point on the first line. TSecond is the transition of the point on the second line.
        """
    @staticmethod
    def SetPeriod_s(theFirstSurf : OCP.Adaptor3d.Adaptor3d_Surface,theSecondSurf : OCP.Adaptor3d.Adaptor3d_Surface,theArrOfPeriod : float) -> None: 
        """
        Fills theArrOfPeriod array by the period values of theFirstSurf and theSecondSurf. [0] = U-period of theFirstSurf, [1] = V-period of theFirstSurf, [2] = U-period of theSecondSurf, [3] = V-period of theSecondSurf.
        """
    def __init__(self) -> None: ...
    pass
class IntSurf_Couple():
    """
    creation d 'un couple de 2 entiers
    """
    def First(self) -> int: 
        """
        returns the first element

        returns the first element
        """
    def Second(self) -> int: 
        """
        returns the Second element

        returns the Second element
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Index1 : int,Index2 : int) -> None: ...
    pass
class IntSurf_InteriorPoint():
    """
    Definition of a point solution of the intersection between an implicit an a parametrised surface. These points are passing points on the intersection lines, or starting points for the closed lines on the parametrised surface.
    """
    def Direction(self) -> OCP.gp.gp_Vec: 
        """
        Returns the tangent at the intersection in 3d space associated to the interior point.

        Returns the tangent at the intersection in 3d space associated to the interior point.
        """
    def Direction2d(self) -> OCP.gp.gp_Vec2d: 
        """
        Returns the tangent at the intersection in the parametric space of the parametric surface.

        Returns the tangent at the intersection in the parametric space of the parametric surface.
        """
    def Parameters(self) -> tuple[float, float]: 
        """
        Returns the parameters of the interior point on the parametric surface.

        Returns the parameters of the interior point on the parametric surface.
        """
    def SetValue(self,P : OCP.gp.gp_Pnt,U : float,V : float,Direc : OCP.gp.gp_Vec,Direc2d : OCP.gp.gp_Vec2d) -> None: ...
    def UParameter(self) -> float: 
        """
        Returns the first parameter of the interior point on the parametric surface.

        Returns the first parameter of the interior point on the parametric surface.
        """
    def VParameter(self) -> float: 
        """
        Returns the second parameter of the interior point on the parametric surface.

        Returns the second parameter of the interior point on the parametric surface.
        """
    def Value(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the 3d coordinates of the interior point.

        Returns the 3d coordinates of the interior point.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Pnt,U : float,V : float,Direc : OCP.gp.gp_Vec,Direc2d : OCP.gp.gp_Vec2d) -> None: ...
    pass
class IntSurf_InteriorPointTool():
    """
    This class provides a tool on the "interior point" that can be used to instantiates the Walking algorithms (see package IntWalk).
    """
    @staticmethod
    def Direction2d_s(PStart : IntSurf_InteriorPoint) -> OCP.gp.gp_Dir2d: 
        """
        returns the tangent at the intersection in the parametric space of the parametrized surface.This tangent is associated to the value2d
        """
    @staticmethod
    def Direction3d_s(PStart : IntSurf_InteriorPoint) -> OCP.gp.gp_Vec: 
        """
        returns the tangent at the intersection in 3d space associated to <P>
        """
    @staticmethod
    def Value2d_s(PStart : IntSurf_InteriorPoint) -> tuple[float, float]: 
        """
        Returns the <U,V> parameters which are associated with <P> it's the parameters which start the marching algorithm
        """
    @staticmethod
    def Value3d_s(PStart : IntSurf_InteriorPoint) -> OCP.gp.gp_Pnt: 
        """
        Returns the 3d coordinates of the starting point.
        """
    def __init__(self) -> None: ...
    pass
class IntSurf_LineOn2S(OCP.Standard.Standard_Transient):
    def Add(self,P : IntSurf_PntOn2S) -> None: 
        """
        Adds a point in the line.
        """
    def Clear(self) -> None: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def InsertBefore(self,I : int,P : IntSurf_PntOn2S) -> None: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsOutBox(self,theP : OCP.gp.gp_Pnt) -> bool: 
        """
        Returns TRUE if theP is out of the box built from 3D-points.
        """
    def IsOutSurf1Box(self,theP : OCP.gp.gp_Pnt2d) -> bool: 
        """
        Returns TRUE if theP is out of the box built from the points on 1st surface
        """
    def IsOutSurf2Box(self,theP : OCP.gp.gp_Pnt2d) -> bool: 
        """
        Returns TRUE if theP is out of the box built from the points on 2nd surface
        """
    def NbPoints(self) -> int: 
        """
        Returns the number of points in the line.

        Returns the number of points in the line.
        """
    def RemovePoint(self,I : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverses the order of points of the line.

        Reverses the order of points of the line.
        """
    def SetPoint(self,Index : int,thePnt : OCP.gp.gp_Pnt) -> None: 
        """
        Sets the 3D point of the Index-th PntOn2S

        Sets the 3D point of the Index-th PntOn2S
        """
    def SetUV(self,Index : int,OnFirst : bool,U : float,V : float) -> None: 
        """
        Sets the parametric coordinates on one of the surfaces of the point of range Index in the line.
        """
    def Split(self,Index : int) -> IntSurf_LineOn2S: 
        """
        Keeps in <me> the points 1 to Index-1, and returns the items Index to the end.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def Value(self,Index : int) -> IntSurf_PntOn2S: 
        """
        Returns the point of range Index in the line.

        Replaces the point of range Index in the line.

        Returns the point of range Index in the line.

        Replaces the point of range Index in the line.
        """
    @overload
    def Value(self,Index : int,P : IntSurf_PntOn2S) -> None: ...
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IntSurf_ListOfPntOn2S(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntSurf_PntOn2S) -> IntSurf_PntOn2S: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : IntSurf_PntOn2S,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : IntSurf_ListOfPntOn2S) -> None: ...
    def Assign(self,theOther : IntSurf_ListOfPntOn2S) -> IntSurf_ListOfPntOn2S: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> IntSurf_PntOn2S: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : IntSurf_PntOn2S,theIter : Any) -> IntSurf_PntOn2S: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : IntSurf_ListOfPntOn2S,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : IntSurf_PntOn2S,theIter : Any) -> IntSurf_PntOn2S: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : IntSurf_ListOfPntOn2S,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> IntSurf_PntOn2S: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : IntSurf_PntOn2S) -> IntSurf_PntOn2S: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : IntSurf_ListOfPntOn2S) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntSurf_ListOfPntOn2S) -> None: ...
    def __iter__(self) -> Iterator[IntSurf_PntOn2S]: ...
    def __len__(self) -> int: ...
    pass
class IntSurf_PathPoint():
    def AddUV(self,U : float,V : float) -> None: ...
    def Direction2d(self) -> OCP.gp.gp_Dir2d: ...
    def Direction3d(self) -> OCP.gp.gp_Vec: ...
    def IsPassingPnt(self) -> bool: ...
    def IsTangent(self) -> bool: ...
    def Multiplicity(self) -> int: ...
    def Parameters(self,Index : int) -> tuple[float, float]: ...
    def SetDirections(self,V : OCP.gp.gp_Vec,D : OCP.gp.gp_Dir2d) -> None: ...
    def SetPassing(self,Pass : bool) -> None: ...
    def SetTangency(self,Tang : bool) -> None: ...
    def SetValue(self,P : OCP.gp.gp_Pnt,U : float,V : float) -> None: ...
    def Value(self) -> OCP.gp.gp_Pnt: ...
    def Value2d(self) -> tuple[float, float]: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Pnt,U : float,V : float) -> None: ...
    pass
class IntSurf_PathPointTool():
    @staticmethod
    def Direction2d_s(PStart : IntSurf_PathPoint) -> OCP.gp.gp_Dir2d: 
        """
        returns the tangent at the intersection in the parametric space of the parametrized surface.This tangent is associated to the value2d la tangente a un sens signifiant (indique le sens de chemin ement) an exception is raised if IsTangent is true.
        """
    @staticmethod
    def Direction3d_s(PStart : IntSurf_PathPoint) -> OCP.gp.gp_Vec: 
        """
        returns the tangent at the intersection in 3d space associated to <P> an exception is raised if IsTangent is true.
        """
    @staticmethod
    def IsPassingPnt_s(PStart : IntSurf_PathPoint) -> bool: 
        """
        Returns True if the point is a point on a non-oriented arc, which means that the intersection line does not stop at such a point but just go through such a point. IsPassingPnt is True when IsOnArc is True
        """
    @staticmethod
    def IsTangent_s(PStart : IntSurf_PathPoint) -> bool: 
        """
        Returns True if the surfaces are tangent at this point. IsTangent can be True when IsOnArc is True if IsPassingPnt is True and IsTangent is True,this point is a stopped point.
        """
    @staticmethod
    def Multiplicity_s(PStart : IntSurf_PathPoint) -> int: 
        """
        Returns the multiplicity of the point i-e the number of auxillar parameters associated to the point which the principal parameters are given by Value2d
        """
    @staticmethod
    def Parameters_s(PStart : IntSurf_PathPoint,Mult : int) -> tuple[float, float]: 
        """
        Parametric coordinates associated to the multiplicity. An exception is raised if Mult<=0 or Mult>multiplicity.
        """
    @staticmethod
    def Value2d_s(PStart : IntSurf_PathPoint) -> tuple[float, float]: 
        """
        Returns the <U, V> parameters which are associated with <P> it's the parameters which start the marching algorithm
        """
    @staticmethod
    def Value3d_s(PStart : IntSurf_PathPoint) -> OCP.gp.gp_Pnt: 
        """
        Returns the 3d coordinates of the starting point.
        """
    def __init__(self) -> None: ...
    pass
class IntSurf_PntOn2S():
    """
    This class defines the geometric information for an intersection point between 2 surfaces : The coordinates ( Pnt from gp ), and two parametric coordinates.
    """
    def IsSame(self,theOtherPoint : IntSurf_PntOn2S,theTol3D : float=0.0,theTol2D : float=-1.0) -> bool: 
        """
        Returns TRUE if 2D- and 3D-coordinates of theOterPoint are equal to corresponding coordinates of me (with given tolerance). If theTol2D < 0.0 we will compare 3D-points only.
        """
    def Parameters(self) -> tuple[float, float, float, float]: 
        """
        Returns the parameters of the point on both surfaces.

        Returns the parameters of the point on both surfaces.
        """
    def ParametersOnS1(self) -> tuple[float, float]: 
        """
        Returns the parameters of the point on the first surface.

        Returns the parameters of the point on the first surface.
        """
    def ParametersOnS2(self) -> tuple[float, float]: 
        """
        Returns the parameters of the point on the second surface.

        Returns the parameters of the point on the second surface.
        """
    def ParametersOnSurface(self,OnFirst : bool) -> tuple[float, float]: 
        """
        Returns the parameters of the point in the parametric space of one of the surface.
        """
    @overload
    def SetValue(self,Pt : OCP.gp.gp_Pnt) -> None: 
        """
        Sets the value of the point in 3d space.

        Sets the values of the point in 3d space, and in the parametric space of one of the surface.

        Sets the values of the point in 3d space, and in the parametric space of each surface.

        Set the values of the point in the parametric space of one of the surface.

        Set the values of the point in the parametric space of one of the surface.

        Sets the value of the point in 3d space.

        Sets the values of the point in 3d space, and in the parametric space of each surface.

        Set the values of the point in the parametric space of one of the surface.
        """
    @overload
    def SetValue(self,Pt : OCP.gp.gp_Pnt,OnFirst : bool,U : float,V : float) -> None: ...
    @overload
    def SetValue(self,Pt : OCP.gp.gp_Pnt,U1 : float,V1 : float,U2 : float,V2 : float) -> None: ...
    @overload
    def SetValue(self,OnFirst : bool,U : float,V : float) -> None: ...
    @overload
    def SetValue(self,U1 : float,V1 : float,U2 : float,V2 : float) -> None: ...
    def Value(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the point in 3d space.

        Returns the point in 3d space.
        """
    def ValueOnSurface(self,OnFirst : bool) -> OCP.gp.gp_Pnt2d: 
        """
        Returns the point in 2d space of one of the surfaces.
        """
    def __init__(self) -> None: ...
    pass
class IntSurf_Quadric():
    def Cone(self) -> OCP.gp.gp_Cone: ...
    def Cylinder(self) -> OCP.gp.gp_Cylinder: ...
    def D1(self,U : float,V : float,P : OCP.gp.gp_Pnt,D1U : OCP.gp.gp_Vec,D1V : OCP.gp.gp_Vec) -> None: ...
    def DN(self,U : float,V : float,Nu : int,Nv : int) -> OCP.gp.gp_Vec: ...
    def Distance(self,P : OCP.gp.gp_Pnt) -> float: ...
    def Gradient(self,P : OCP.gp.gp_Pnt) -> OCP.gp.gp_Vec: ...
    @overload
    def Normale(self,U : float,V : float) -> OCP.gp.gp_Vec: ...
    @overload
    def Normale(self,P : OCP.gp.gp_Pnt) -> OCP.gp.gp_Vec: ...
    def Parameters(self,P : OCP.gp.gp_Pnt) -> tuple[float, float]: ...
    def Plane(self) -> OCP.gp.gp_Pln: ...
    @overload
    def SetValue(self,P : OCP.gp.gp_Pln) -> None: ...
    @overload
    def SetValue(self,C : OCP.gp.gp_Cylinder) -> None: ...
    @overload
    def SetValue(self,S : OCP.gp.gp_Sphere) -> None: ...
    @overload
    def SetValue(self,C : OCP.gp.gp_Cone) -> None: ...
    @overload
    def SetValue(self,T : OCP.gp.gp_Torus) -> None: ...
    def Sphere(self) -> OCP.gp.gp_Sphere: ...
    def Torus(self) -> OCP.gp.gp_Torus: ...
    def TypeQuadric(self) -> OCP.GeomAbs.GeomAbs_SurfaceType: ...
    def ValAndGrad(self,P : OCP.gp.gp_Pnt,Grad : OCP.gp.gp_Vec) -> tuple[float]: ...
    def Value(self,U : float,V : float) -> OCP.gp.gp_Pnt: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Pln) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Cylinder) -> None: ...
    @overload
    def __init__(self,S : OCP.gp.gp_Sphere) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Cone) -> None: ...
    @overload
    def __init__(self,T : OCP.gp.gp_Torus) -> None: ...
    pass
class IntSurf_QuadricTool():
    """
    This class provides a tool on a quadric that can be used to instantiates the Walking algorithms (see package IntWalk) with a Quadric from IntSurf as implicit surface.
    """
    @staticmethod
    def Gradient_s(Quad : IntSurf_Quadric,X : float,Y : float,Z : float,V : OCP.gp.gp_Vec) -> None: 
        """
        Returns the gradient of the function.
        """
    @staticmethod
    def Tolerance_s(Quad : IntSurf_Quadric) -> float: 
        """
        returns the tolerance of the zero of the implicit function
        """
    @staticmethod
    def ValueAndGradient_s(Quad : IntSurf_Quadric,X : float,Y : float,Z : float,Grad : OCP.gp.gp_Vec) -> tuple[float]: 
        """
        Returns the value and the gradient.
        """
    @staticmethod
    def Value_s(Quad : IntSurf_Quadric,X : float,Y : float,Z : float) -> float: 
        """
        Returns the value of the function.
        """
    def __init__(self) -> None: ...
    pass
class IntSurf_SequenceOfCouple(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntSurf_Couple) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : IntSurf_SequenceOfCouple) -> None: ...
    def Assign(self,theOther : IntSurf_SequenceOfCouple) -> IntSurf_SequenceOfCouple: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> IntSurf_Couple: 
        """
        First item access
        """
    def ChangeLast(self) -> IntSurf_Couple: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> IntSurf_Couple: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> IntSurf_Couple: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : IntSurf_SequenceOfCouple) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : IntSurf_Couple) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : IntSurf_Couple) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : IntSurf_SequenceOfCouple) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> IntSurf_Couple: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : IntSurf_Couple) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : IntSurf_SequenceOfCouple) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : IntSurf_Couple) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : IntSurf_SequenceOfCouple) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> IntSurf_Couple: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> IntSurf_Couple: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntSurf_SequenceOfCouple) -> None: ...
    def __iter__(self) -> Iterator[IntSurf_Couple]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class IntSurf_SequenceOfInteriorPoint(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntSurf_InteriorPoint) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : IntSurf_SequenceOfInteriorPoint) -> None: ...
    def Assign(self,theOther : IntSurf_SequenceOfInteriorPoint) -> IntSurf_SequenceOfInteriorPoint: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> IntSurf_InteriorPoint: 
        """
        First item access
        """
    def ChangeLast(self) -> IntSurf_InteriorPoint: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> IntSurf_InteriorPoint: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> IntSurf_InteriorPoint: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : IntSurf_SequenceOfInteriorPoint) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : IntSurf_InteriorPoint) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : IntSurf_InteriorPoint) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : IntSurf_SequenceOfInteriorPoint) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> IntSurf_InteriorPoint: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : IntSurf_InteriorPoint) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : IntSurf_SequenceOfInteriorPoint) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : IntSurf_InteriorPoint) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : IntSurf_SequenceOfInteriorPoint) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> IntSurf_InteriorPoint: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> IntSurf_InteriorPoint: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntSurf_SequenceOfInteriorPoint) -> None: ...
    def __iter__(self) -> Iterator[IntSurf_InteriorPoint]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class IntSurf_SequenceOfPathPoint(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntSurf_PathPoint) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : IntSurf_SequenceOfPathPoint) -> None: ...
    def Assign(self,theOther : IntSurf_SequenceOfPathPoint) -> IntSurf_SequenceOfPathPoint: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> IntSurf_PathPoint: 
        """
        First item access
        """
    def ChangeLast(self) -> IntSurf_PathPoint: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> IntSurf_PathPoint: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> IntSurf_PathPoint: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : IntSurf_SequenceOfPathPoint) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : IntSurf_PathPoint) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : IntSurf_PathPoint) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : IntSurf_SequenceOfPathPoint) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> IntSurf_PathPoint: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : IntSurf_PathPoint) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : IntSurf_SequenceOfPathPoint) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : IntSurf_PathPoint) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : IntSurf_SequenceOfPathPoint) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> IntSurf_PathPoint: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> IntSurf_PathPoint: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntSurf_SequenceOfPathPoint) -> None: ...
    def __iter__(self) -> Iterator[IntSurf_PathPoint]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class IntSurf_SequenceOfPntOn2S(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntSurf_PntOn2S) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : IntSurf_SequenceOfPntOn2S) -> None: ...
    def Assign(self,theOther : IntSurf_SequenceOfPntOn2S) -> IntSurf_SequenceOfPntOn2S: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> IntSurf_PntOn2S: 
        """
        First item access
        """
    def ChangeLast(self) -> IntSurf_PntOn2S: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> IntSurf_PntOn2S: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> IntSurf_PntOn2S: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : IntSurf_SequenceOfPntOn2S) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : IntSurf_PntOn2S) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : IntSurf_PntOn2S) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : IntSurf_SequenceOfPntOn2S) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> IntSurf_PntOn2S: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : IntSurf_PntOn2S) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : IntSurf_SequenceOfPntOn2S) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : IntSurf_PntOn2S) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : IntSurf_SequenceOfPntOn2S) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> IntSurf_PntOn2S: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> IntSurf_PntOn2S: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntSurf_SequenceOfPntOn2S) -> None: ...
    def __iter__(self) -> Iterator[IntSurf_PntOn2S]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class IntSurf_Situation():
    """
    Members:

      IntSurf_Inside

      IntSurf_Outside

      IntSurf_Unknown
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    IntSurf_Inside: OCP.IntSurf.IntSurf_Situation # value = <IntSurf_Situation.IntSurf_Inside: 0>
    IntSurf_Outside: OCP.IntSurf.IntSurf_Situation # value = <IntSurf_Situation.IntSurf_Outside: 1>
    IntSurf_Unknown: OCP.IntSurf.IntSurf_Situation # value = <IntSurf_Situation.IntSurf_Unknown: 2>
    __entries: dict # value = {'IntSurf_Inside': (<IntSurf_Situation.IntSurf_Inside: 0>, None), 'IntSurf_Outside': (<IntSurf_Situation.IntSurf_Outside: 1>, None), 'IntSurf_Unknown': (<IntSurf_Situation.IntSurf_Unknown: 2>, None)}
    __members__: dict # value = {'IntSurf_Inside': <IntSurf_Situation.IntSurf_Inside: 0>, 'IntSurf_Outside': <IntSurf_Situation.IntSurf_Outside: 1>, 'IntSurf_Unknown': <IntSurf_Situation.IntSurf_Unknown: 2>}
    pass
class IntSurf_Transition():
    """
    Definition of the transition at the intersection between an intersection line and a restriction curve on a surface.
    """
    def IsOpposite(self) -> bool: 
        """
        returns a significant value if TransitionType returns TOUCH. In this case, the function returns true when the 2 curves locally define two different parts of the space. If TransitionType returns IN or OUT or UNDECIDED, an exception is raised.

        returns a significant value if TransitionType returns TOUCH. In this case, the function returns true when the 2 curves locally define two different parts of the space. If TransitionType returns IN or OUT or UNDECIDED, an exception is raised.
        """
    def IsTangent(self) -> bool: 
        """
        Returns TRUE if the point is tangent to the arc given by Value. An exception is raised if TransitionType returns UNDECIDED.

        Returns TRUE if the point is tangent to the arc given by Value. An exception is raised if TransitionType returns UNDECIDED.
        """
    @overload
    def SetValue(self,Tangent : bool,Type : IntSurf_TypeTrans) -> None: 
        """
        Set the values of an IN or OUT transition.

        Set the values of a TOUCH transition.

        Set the values of an UNDECIDED transition.

        Set the values of an IN or OUT transition.

        Set the values of a TOUCH transition.

        Set the values of an UNDECIDED transition.
        """
    @overload
    def SetValue(self,Tangent : bool,Situ : IntSurf_Situation,Oppos : bool) -> None: ...
    @overload
    def SetValue(self) -> None: ...
    def Situation(self) -> IntSurf_Situation: 
        """
        Returns a significant value if TransitionType returns TOUCH. In this case, the function returns : INSIDE when the intersection line remains inside the Arc, OUTSIDE when it remains outside the Arc, UNKNOWN when the calsulus cannot give results. If TransitionType returns IN, or OUT, or UNDECIDED, a exception is raised.

        Returns a significant value if TransitionType returns TOUCH. In this case, the function returns : INSIDE when the intersection line remains inside the Arc, OUTSIDE when it remains outside the Arc, UNKNOWN when the calsulus cannot give results. If TransitionType returns IN, or OUT, or UNDECIDED, a exception is raised.
        """
    def TransitionType(self) -> IntSurf_TypeTrans: 
        """
        Returns the type of Transition (in/out/touch/undecided) for the arc given by value. This the transition of the intersection line compared to the Arc of restriction, i-e when the function returns INSIDE for example, it means that the intersection line goes inside the part of plane limited by the arc of restriction.

        Returns the type of Transition (in/out/touch/undecided) for the arc given by value. This the transition of the intersection line compared to the Arc of restriction, i-e when the function returns INSIDE for example, it means that the intersection line goes inside the part of plane limited by the arc of restriction.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Tangent : bool,Type : IntSurf_TypeTrans) -> None: ...
    @overload
    def __init__(self,Tangent : bool,Situ : IntSurf_Situation,Oppos : bool) -> None: ...
    pass
class IntSurf_TypeTrans():
    """
    Members:

      IntSurf_In

      IntSurf_Out

      IntSurf_Touch

      IntSurf_Undecided
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    IntSurf_In: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_In: 0>
    IntSurf_Out: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_Out: 1>
    IntSurf_Touch: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_Touch: 2>
    IntSurf_Undecided: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_Undecided: 3>
    __entries: dict # value = {'IntSurf_In': (<IntSurf_TypeTrans.IntSurf_In: 0>, None), 'IntSurf_Out': (<IntSurf_TypeTrans.IntSurf_Out: 1>, None), 'IntSurf_Touch': (<IntSurf_TypeTrans.IntSurf_Touch: 2>, None), 'IntSurf_Undecided': (<IntSurf_TypeTrans.IntSurf_Undecided: 3>, None)}
    __members__: dict # value = {'IntSurf_In': <IntSurf_TypeTrans.IntSurf_In: 0>, 'IntSurf_Out': <IntSurf_TypeTrans.IntSurf_Out: 1>, 'IntSurf_Touch': <IntSurf_TypeTrans.IntSurf_Touch: 2>, 'IntSurf_Undecided': <IntSurf_TypeTrans.IntSurf_Undecided: 3>}
    pass
IntSurf_In: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_In: 0>
IntSurf_Inside: OCP.IntSurf.IntSurf_Situation # value = <IntSurf_Situation.IntSurf_Inside: 0>
IntSurf_Out: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_Out: 1>
IntSurf_Outside: OCP.IntSurf.IntSurf_Situation # value = <IntSurf_Situation.IntSurf_Outside: 1>
IntSurf_Touch: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_Touch: 2>
IntSurf_Undecided: OCP.IntSurf.IntSurf_TypeTrans # value = <IntSurf_TypeTrans.IntSurf_Undecided: 3>
IntSurf_Unknown: OCP.IntSurf.IntSurf_Situation # value = <IntSurf_Situation.IntSurf_Unknown: 2>



import OCP.IGESFile
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.IGESData
__all__  = [
"IGESFile_Read",
"IGESFile_ReadFNES"
]
@overload
def IGESFile_Read(nomfic : str,amodel : OCP.IGESData.IGESData_IGESModel,protocol : OCP.IGESData.IGESData_Protocol) -> int:
    pass
@overload
def IGESFile_Read(nomfic : str,amodel : OCP.IGESData.IGESData_IGESModel,protocol : OCP.IGESData.IGESData_Protocol,reco : OCP.IGESData.IGESData_FileRecognizer,modefnes : bool=False) -> int:
    pass
def IGESFile_ReadFNES(nomfic : str,amodel : OCP.IGESData.IGESData_IGESModel,protocol : OCP.IGESData.IGESData_Protocol) -> int:
    pass



import OCP.BSplSLib
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
import OCP.TColStd
import OCP.gp
import OCP.TColgp
__all__  = [
"BSplSLib",
"BSplSLib_Cache",
"BSplSLib_EvaluatorFunction"
]
class BSplSLib():
    """
    BSplSLib B-spline surface Library This package provides an implementation of geometric functions for rational and non rational, periodic and non periodic B-spline surface computation.
    """
    @staticmethod
    @overload
    def BuildCache_s(U : float,V : float,USpanDomain : float,VSpanDomain : float,UPeriodicFlag : bool,VPeriodicFlag : bool,UDegree : int,VDegree : int,UIndex : int,VIndex : int,UFlatKnots : OCP.TColStd.TColStd_Array1OfReal,VFlatKnots : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,CachePoles : OCP.TColgp.TColgp_Array2OfPnt,CacheWeights : OCP.TColStd.TColStd_Array2OfReal) -> None: 
        """
        Perform the evaluation of the Taylor expansion of the Bspline normalized between 0 and 1. If rational computes the homogeneous Taylor expansion for the numerator and stores it in CachePoles

        Perform the evaluation of the Taylor expansion of the Bspline normalized between 0 and 1. Structure of result optimized for BSplSLib_Cache.
        """
    @staticmethod
    @overload
    def BuildCache_s(theU : float,theV : float,theUSpanDomain : float,theVSpanDomain : float,theUPeriodic : bool,theVPeriodic : bool,theUDegree : int,theVDegree : int,theUIndex : int,theVIndex : int,theUFlatKnots : OCP.TColStd.TColStd_Array1OfReal,theVFlatKnots : OCP.TColStd.TColStd_Array1OfReal,thePoles : OCP.TColgp.TColgp_Array2OfPnt,theWeights : OCP.TColStd.TColStd_Array2OfReal,theCacheArray : OCP.TColStd.TColStd_Array2OfReal) -> None: ...
    @staticmethod
    def CacheD0_s(U : float,V : float,UDegree : int,VDegree : int,UCacheParameter : float,VCacheParameter : float,USpanLenght : float,VSpanLength : float,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Point : OCP.gp.gp_Pnt) -> None: 
        """
        Perform the evaluation of the of the cache the parameter must be normalized between the 0 and 1 for the span. The Cache must be valid when calling this routine. Geom Package will insure that. and then multiplies by the weights this just evaluates the current point the CacheParameter is where the Cache was constructed the SpanLength is to normalize the polynomial in the cache to avoid bad conditioning effects
        """
    @staticmethod
    def CacheD1_s(U : float,V : float,UDegree : int,VDegree : int,UCacheParameter : float,VCacheParameter : float,USpanLenght : float,VSpanLength : float,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Point : OCP.gp.gp_Pnt,VecU : OCP.gp.gp_Vec,VecV : OCP.gp.gp_Vec) -> None: 
        """
        Perform the evaluation of the of the cache the parameter must be normalized between the 0 and 1 for the span. The Cache must be valid when calling this routine. Geom Package will insure that. and then multiplies by the weights this just evaluates the current point the CacheParameter is where the Cache was constructed the SpanLength is to normalize the polynomial in the cache to avoid bad conditioning effects
        """
    @staticmethod
    def CacheD2_s(U : float,V : float,UDegree : int,VDegree : int,UCacheParameter : float,VCacheParameter : float,USpanLenght : float,VSpanLength : float,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Point : OCP.gp.gp_Pnt,VecU : OCP.gp.gp_Vec,VecV : OCP.gp.gp_Vec,VecUU : OCP.gp.gp_Vec,VecUV : OCP.gp.gp_Vec,VecVV : OCP.gp.gp_Vec) -> None: 
        """
        Perform the evaluation of the of the cache the parameter must be normalized between the 0 and 1 for the span. The Cache must be valid when calling this routine. Geom Package will insure that. and then multiplies by the weights this just evaluates the current point the CacheParameter is where the Cache was constructed the SpanLength is to normalize the polynomial in the cache to avoid bad conditioning effects
        """
    @staticmethod
    def CoefsD0_s(U : float,V : float,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Point : OCP.gp.gp_Pnt) -> None: 
        """
        Calls CacheD0 for Bezier Surfaces Arrays computed with the method PolesCoefficients. Warning: To be used for BezierSurfaces ONLY!!!
        """
    @staticmethod
    def CoefsD1_s(U : float,V : float,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Point : OCP.gp.gp_Pnt,VecU : OCP.gp.gp_Vec,VecV : OCP.gp.gp_Vec) -> None: 
        """
        Calls CacheD0 for Bezier Surfaces Arrays computed with the method PolesCoefficients. Warning: To be used for BezierSurfaces ONLY!!!
        """
    @staticmethod
    def CoefsD2_s(U : float,V : float,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Point : OCP.gp.gp_Pnt,VecU : OCP.gp.gp_Vec,VecV : OCP.gp.gp_Vec,VecUU : OCP.gp.gp_Vec,VecUV : OCP.gp.gp_Vec,VecVV : OCP.gp.gp_Vec) -> None: 
        """
        Calls CacheD0 for Bezier Surfaces Arrays computed with the method PolesCoefficients. Warning: To be used for BezierSurfaces ONLY!!!
        """
    @staticmethod
    def D0_s(U : float,V : float,UIndex : int,VIndex : int,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,UDegree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,P : OCP.gp.gp_Pnt) -> None: ...
    @staticmethod
    def D1_s(U : float,V : float,UIndex : int,VIndex : int,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,Degree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,P : OCP.gp.gp_Pnt,Vu : OCP.gp.gp_Vec,Vv : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    def D2_s(U : float,V : float,UIndex : int,VIndex : int,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,UDegree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,P : OCP.gp.gp_Pnt,Vu : OCP.gp.gp_Vec,Vv : OCP.gp.gp_Vec,Vuu : OCP.gp.gp_Vec,Vvv : OCP.gp.gp_Vec,Vuv : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    def D3_s(U : float,V : float,UIndex : int,VIndex : int,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,UDegree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,P : OCP.gp.gp_Pnt,Vu : OCP.gp.gp_Vec,Vv : OCP.gp.gp_Vec,Vuu : OCP.gp.gp_Vec,Vvv : OCP.gp.gp_Vec,Vuv : OCP.gp.gp_Vec,Vuuu : OCP.gp.gp_Vec,Vvvv : OCP.gp.gp_Vec,Vuuv : OCP.gp.gp_Vec,Vuvv : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    def DN_s(U : float,V : float,Nu : int,Nv : int,UIndex : int,VIndex : int,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,UDegree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,Vn : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    def FunctionMultiply_s(Function : BSplSLib_EvaluatorFunction,UBSplineDegree : int,VBSplineDegree : int,UBSplineKnots : OCP.TColStd.TColStd_Array1OfReal,VBSplineKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UFlatKnots : OCP.TColStd.TColStd_Array1OfReal,VFlatKnots : OCP.TColStd.TColStd_Array1OfReal,UNewDegree : int,VNewDegree : int,NewNumerator : OCP.TColgp.TColgp_Array2OfPnt,NewDenominator : OCP.TColStd.TColStd_Array2OfReal) -> tuple[int]: 
        """
        this will multiply a given BSpline numerator N(u,v) and denominator D(u,v) defined by its U/VBSplineDegree and U/VBSplineKnots, and U/VMults. Its Poles and Weights are arrays which are coded as array2 of the form [1..UNumPoles][1..VNumPoles] by a function a(u,v) which is assumed to satisfy the following : 1. a(u,v) * N(u,v) and a(u,v) * D(u,v) is a polynomial BSpline that can be expressed exactly as a BSpline of degree U/VNewDegree on the knots U/VFlatKnots 2. the range of a(u,v) is the same as the range of N(u,v) or D(u,v) ---Warning: it is the caller's responsibility to insure that conditions 1. and 2. above are satisfied : no check whatsoever is made in this method -- theStatus will return 0 if OK else it will return the pivot index -- of the matrix that was inverted to compute the multiplied -- BSpline : the method used is interpolation at Schoenenberg -- points of a(u,v)* N(u,v) and a(u,v) * D(u,v) theStatus will return 0 if OK else it will return the pivot index of the matrix that was inverted to compute the multiplied BSpline : the method used is interpolation at Schoenenberg points of a(u,v)*F(u,v) --
        """
    @staticmethod
    @overload
    def GetPoles_s(FP : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array2OfPnt,UDirection : bool) -> None: 
        """
        Get from FP the coordinates of the poles.

        Get from FP the coordinates of the poles.
        """
    @staticmethod
    @overload
    def GetPoles_s(FP : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UDirection : bool) -> None: ...
    @staticmethod
    def HomogeneousD0_s(U : float,V : float,UIndex : int,VIndex : int,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,UDegree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,P : OCP.gp.gp_Pnt) -> tuple[float]: 
        """
        Makes an homogeneous evaluation of Poles and Weights any and returns in P the Numerator value and in W the Denominator value if Weights are present otherwise returns 1.0e0
        """
    @staticmethod
    def HomogeneousD1_s(U : float,V : float,UIndex : int,VIndex : int,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,UDegree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,N : OCP.gp.gp_Pnt,Nu : OCP.gp.gp_Vec,Nv : OCP.gp.gp_Vec) -> tuple[float, float, float]: 
        """
        Makes an homogeneous evaluation of Poles and Weights any and returns in P the Numerator value and in W the Denominator value if Weights are present otherwise returns 1.0e0
        """
    @staticmethod
    def IncreaseDegree_s(UDirection : bool,Degree : int,NewDegree : int,Periodic : bool,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Knots : OCP.TColStd.TColStd_Array1OfReal,Mults : OCP.TColStd.TColStd_Array1OfInteger,NewPoles : OCP.TColgp.TColgp_Array2OfPnt,NewWeights : OCP.TColStd.TColStd_Array2OfReal,NewKnots : OCP.TColStd.TColStd_Array1OfReal,NewMults : OCP.TColStd.TColStd_Array1OfInteger) -> None: ...
    @staticmethod
    def InsertKnots_s(UDirection : bool,Degree : int,Periodic : bool,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Knots : OCP.TColStd.TColStd_Array1OfReal,Mults : OCP.TColStd.TColStd_Array1OfInteger,AddKnots : OCP.TColStd.TColStd_Array1OfReal,AddMults : OCP.TColStd.TColStd_Array1OfInteger,NewPoles : OCP.TColgp.TColgp_Array2OfPnt,NewWeights : OCP.TColStd.TColStd_Array2OfReal,NewKnots : OCP.TColStd.TColStd_Array1OfReal,NewMults : OCP.TColStd.TColStd_Array1OfInteger,Epsilon : float,Add : bool=True) -> None: ...
    @staticmethod
    @overload
    def Interpolate_s(UDegree : int,VDegree : int,UFlatKnots : OCP.TColStd.TColStd_Array1OfReal,VFlatKnots : OCP.TColStd.TColStd_Array1OfReal,UParameters : OCP.TColStd.TColStd_Array1OfReal,VParameters : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal) -> tuple[int]: 
        """
        Performs the interpolation of the data points given in the Poles array in the form [1,...,RL][1,...,RC][1...PolesDimension] . The ColLength CL and the Length of UParameters must be the same. The length of VFlatKnots is VDegree + CL + 1.

        Performs the interpolation of the data points given in the Poles array. The ColLength CL and the Length of UParameters must be the same. The length of VFlatKnots is VDegree + CL + 1.
        """
    @staticmethod
    @overload
    def Interpolate_s(UDegree : int,VDegree : int,UFlatKnots : OCP.TColStd.TColStd_Array1OfReal,VFlatKnots : OCP.TColStd.TColStd_Array1OfReal,UParameters : OCP.TColStd.TColStd_Array1OfReal,VParameters : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array2OfPnt) -> tuple[int]: ...
    @staticmethod
    def IsRational_s(Weights : OCP.TColStd.TColStd_Array2OfReal,I1 : int,I2 : int,J1 : int,J2 : int,Epsilon : float=0.0) -> bool: 
        """
        Returns False if all the weights of the array <Weights> in the area [I1,I2] * [J1,J2] are identic. Epsilon is used for comparing weights. If Epsilon is 0. the Epsilon of the first weight is used.
        """
    @staticmethod
    def Iso_s(Param : float,IsU : bool,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Knots : OCP.TColStd.TColStd_Array1OfReal,Mults : OCP.TColStd.TColStd_Array1OfInteger,Degree : int,Periodic : bool,CPoles : OCP.TColgp.TColgp_Array1OfPnt,CWeights : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Computes the poles and weights of an isoparametric curve at parameter <Param> (UIso if <IsU> is True, VIso else).
        """
    @staticmethod
    def MovePoint_s(U : float,V : float,Displ : OCP.gp.gp_Vec,UIndex1 : int,UIndex2 : int,VIndex1 : int,VIndex2 : int,UDegree : int,VDegree : int,Rational : bool,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UFlatKnots : OCP.TColStd.TColStd_Array1OfReal,VFlatKnots : OCP.TColStd.TColStd_Array1OfReal,NewPoles : OCP.TColgp.TColgp_Array2OfPnt) -> tuple[int, int, int, int]: 
        """
        Find the new poles which allows an old point (with a given u,v as parameters) to reach a new position UIndex1,UIndex2 indicate the range of poles we can move for U (1, UNbPoles-1) or (2, UNbPoles) -> no constraint for one side in U (2, UNbPoles-1) -> the ends are enforced for U don't enter (1,NbPoles) and (1,VNbPoles) -> error: rigid move if problem in BSplineBasis calculation, no change for the curve and UFirstIndex, VLastIndex = 0 VFirstIndex, VLastIndex = 0
        """
    @staticmethod
    def NoWeights_s() -> OCP.TColStd.TColStd_Array2OfReal: 
        """
        Used as argument for a non rational curve.
        """
    @staticmethod
    @overload
    def PolesCoefficients_s(Poles : OCP.TColgp.TColgp_Array2OfPnt,CachePoles : OCP.TColgp.TColgp_Array2OfPnt) -> None: 
        """
        Warning! To be used for BezierSurfaces ONLY!!!

        Encapsulation of BuildCache to perform the evaluation of the Taylor expansion for beziersurfaces at parameters 0.,0.; Warning: To be used for BezierSurfaces ONLY!!!
        """
    @staticmethod
    @overload
    def PolesCoefficients_s(Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,CachePoles : OCP.TColgp.TColgp_Array2OfPnt,CacheWeights : OCP.TColStd.TColStd_Array2OfReal) -> None: ...
    @staticmethod
    def RationalDerivative_s(UDeg : int,VDeg : int,N : int,M : int,All : bool=True) -> tuple[float, float]: 
        """
        this is a one dimensional function typedef void (*EvaluatorFunction) ( Standard_Integer // Derivative Request Standard_Real * // StartEnd[2][2] // [0] = U // [1] = V // [0] = start // [1] = end Standard_Real // UParameter Standard_Real // VParamerer Standard_Real & // Result Standard_Integer &) ;// Error Code serves to multiply a given vectorial BSpline by a function Computes the derivatives of a ratio of two-variables functions x(u,v) / w(u,v) at orders <N,M>, x(u,v) is a vector in dimension <3>.
        """
    @staticmethod
    def RemoveKnot_s(UDirection : bool,Index : int,Mult : int,Degree : int,Periodic : bool,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,Knots : OCP.TColStd.TColStd_Array1OfReal,Mults : OCP.TColStd.TColStd_Array1OfInteger,NewPoles : OCP.TColgp.TColgp_Array2OfPnt,NewWeights : OCP.TColStd.TColStd_Array2OfReal,NewKnots : OCP.TColStd.TColStd_Array1OfReal,NewMults : OCP.TColStd.TColStd_Array1OfInteger,Tolerance : float) -> bool: ...
    @staticmethod
    def Resolution_s(Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UMults : OCP.TColStd.TColStd_Array1OfInteger,VMults : OCP.TColStd.TColStd_Array1OfInteger,UDegree : int,VDegree : int,URat : bool,VRat : bool,UPer : bool,VPer : bool,Tolerance3D : float) -> tuple[float, float]: 
        """
        Given a tolerance in 3D space returns two tolerances, one in U one in V such that for all (u1,v1) and (u0,v0) in the domain of the surface f(u,v) we have : | u1 - u0 | < UTolerance and | v1 - v0 | < VTolerance we have |f (u1,v1) - f (u0,v0)| < Tolerance3D
        """
    @staticmethod
    @overload
    def Reverse_s(Poles : OCP.TColgp.TColgp_Array2OfPnt,Last : int,UDirection : bool) -> None: 
        """
        Reverses the array of poles. Last is the Index of the new first Row( Col) of Poles. On a non periodic surface Last is Poles.Upper(). On a periodic curve last is (number of flat knots - degree - 1) or (sum of multiplicities(but for the last) + degree - 1)

        Reverses the array of weights.
        """
    @staticmethod
    @overload
    def Reverse_s(Weights : OCP.TColStd.TColStd_Array2OfReal,Last : int,UDirection : bool) -> None: ...
    @staticmethod
    @overload
    def SetPoles_s(Poles : OCP.TColgp.TColgp_Array2OfPnt,FP : OCP.TColStd.TColStd_Array1OfReal,UDirection : bool) -> None: 
        """
        Copy in FP the coordinates of the poles.

        Copy in FP the coordinates of the poles.
        """
    @staticmethod
    @overload
    def SetPoles_s(Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,FP : OCP.TColStd.TColStd_Array1OfReal,UDirection : bool) -> None: ...
    @staticmethod
    def Unperiodize_s(UDirection : bool,Degree : int,Mults : OCP.TColStd.TColStd_Array1OfInteger,Knots : OCP.TColStd.TColStd_Array1OfReal,Poles : OCP.TColgp.TColgp_Array2OfPnt,Weights : OCP.TColStd.TColStd_Array2OfReal,NewMults : OCP.TColStd.TColStd_Array1OfInteger,NewKnots : OCP.TColStd.TColStd_Array1OfReal,NewPoles : OCP.TColgp.TColgp_Array2OfPnt,NewWeights : OCP.TColStd.TColStd_Array2OfReal) -> None: ...
    def __init__(self) -> None: ...
    pass
class BSplSLib_Cache(OCP.Standard.Standard_Transient):
    """
    A cache class for Bezier and B-spline surfaces.A cache class for Bezier and B-spline surfaces.
    """
    def BuildCache(self,theParameterU : float,theParameterV : float,theFlatKnotsU : OCP.TColStd.TColStd_Array1OfReal,theFlatKnotsV : OCP.TColStd.TColStd_Array1OfReal,thePoles : OCP.TColgp.TColgp_Array2OfPnt,theWeights : OCP.TColStd.TColStd_Array2OfReal=None) -> None: 
        """
        Recomputes the cache data. Does not verify validity of the cache
        """
    def D0(self,theU : float,theV : float,thePoint : OCP.gp.gp_Pnt) -> None: 
        """
        Calculates the point on the surface for specified parameters
        """
    def D1(self,theU : float,theV : float,thePoint : OCP.gp.gp_Pnt,theTangentU : OCP.gp.gp_Vec,theTangentV : OCP.gp.gp_Vec) -> None: 
        """
        Calculates the point on the surface and its first derivative
        """
    def D2(self,theU : float,theV : float,thePoint : OCP.gp.gp_Pnt,theTangentU : OCP.gp.gp_Vec,theTangentV : OCP.gp.gp_Vec,theCurvatureU : OCP.gp.gp_Vec,theCurvatureV : OCP.gp.gp_Vec,theCurvatureUV : OCP.gp.gp_Vec) -> None: 
        """
        Calculates the point on the surface and derivatives till second order
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsCacheValid(self,theParameterU : float,theParameterV : float) -> bool: 
        """
        Verifies validity of the cache using parameters of the point
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self,theDegreeU : int,thePeriodicU : bool,theFlatKnotsU : OCP.TColStd.TColStd_Array1OfReal,theDegreeV : int,thePeriodicV : bool,theFlatKnotsV : OCP.TColStd.TColStd_Array1OfReal,theWeights : OCP.TColStd.TColStd_Array2OfReal=None) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BSplSLib_EvaluatorFunction():
    def Evaluate(self,theDerivativeRequest : int,theUParameter : float,theVParameter : float) -> tuple[float, int]: 
        """
        Function evaluation method to be defined by descendant
        """
    def __call__(self,theDerivativeRequest : int,theUParameter : float,theVParameter : float,theResult : float,theErrorCode : int) -> None: 
        """
        Shortcut for function-call style usage
        """
    def __init__(self) -> None: ...
    pass



import OCP.XmlMDF
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import OCP.Message
import OCP.XmlObjMgt
import OCP.Standard
import OCP.LDOM
import OCP.TDF
__all__  = [
"XmlMDF",
"XmlMDF_ADriver",
"XmlMDF_ADriverTable",
"XmlMDF_DerivedDriver",
"XmlMDF_ReferenceDriver",
"XmlMDF_TagSourceDriver"
]
class XmlMDF():
    """
    This package provides classes and methods to translate a transient DF into a persistent one and vice versa.
    """
    @staticmethod
    def AddDrivers_s(aDriverTable : XmlMDF_ADriverTable,theMessageDriver : OCP.Message.Message_Messenger) -> None: 
        """
        Adds the attribute storage drivers to <aDriverSeq>.
        """
    @staticmethod
    @overload
    def FromTo_s(aSource : OCP.TDF.TDF_Data,aTarget : OCP.LDOM.LDOM_Element,aReloc : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable,aDrivers : XmlMDF_ADriverTable,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        Translates a transient <aSource> into a persistent <aTarget>.

        Translates a persistent <aSource> into a transient <aTarget>. Returns True if completed successfully (False on error)
        """
    @staticmethod
    @overload
    def FromTo_s(aSource : OCP.LDOM.LDOM_Element,aTarget : OCP.TDF.TDF_Data,aReloc : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable,aDrivers : XmlMDF_ADriverTable,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: ...
    def __init__(self) -> None: ...
    pass
class XmlMDF_ADriver(OCP.Standard.Standard_Transient):
    """
    Attribute Storage/Retrieval Driver.Attribute Storage/Retrieval Driver.Attribute Storage/Retrieval Driver.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: 
        """
        Creates a new attribute from TDF.
        """
    @overload
    def Paste(self,aSource : OCP.XmlObjMgt.XmlObjMgt_Persistent,aTarget : OCP.TDF.TDF_Attribute,aRelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: 
        """
        Translate the contents of <aSource> and put it into <aTarget>, using the relocation table <aRelocTable> to keep the sharings.

        Translate the contents of <aSource> and put it into <aTarget>, using the relocation table <aRelocTable> to keep the sharings.
        """
    @overload
    def Paste(self,aSource : OCP.TDF.TDF_Attribute,aTarget : OCP.XmlObjMgt.XmlObjMgt_Persistent,aRelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlMDF_ADriverTable(OCP.Standard.Standard_Transient):
    """
    A driver table is an object building links between object types and object drivers. In the translation process, a driver table is asked to give a translation driver for each current object to be translated.A driver table is an object building links between object types and object drivers. In the translation process, a driver table is asked to give a translation driver for each current object to be translated.A driver table is an object building links between object types and object drivers. In the translation process, a driver table is asked to give a translation driver for each current object to be translated.
    """
    @overload
    def AddDerivedDriver(self,theInstance : OCP.TDF.TDF_Attribute) -> None: 
        """
        Adds a translation driver for the derived attribute. The base driver must be already added.

        Adds a translation driver for the derived attribute. The base driver must be already added.
        """
    @overload
    def AddDerivedDriver(self,theDerivedType : str) -> OCP.Standard.Standard_Type: ...
    def AddDriver(self,anHDriver : XmlMDF_ADriver) -> None: 
        """
        Sets a translation driver: <aDriver>.
        """
    def CreateDrvMap(self,theDriverMap : Any) -> None: 
        """
        Fills the map by all registered drivers.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetDriver(self,theType : OCP.Standard.Standard_Type,theDriver : XmlMDF_ADriver) -> bool: 
        """
        Gets a driver <aDriver> according to <aType>
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlMDF_DerivedDriver(XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    """
    A universal driver for the attribute that inherits another attribute with ready to used persistence mechanism implemented (already has a driver to store/retrieve).
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: 
        """
        Creates a new instance of the derivative attribute
        """
    @overload
    def Paste(self,theSource : OCP.XmlObjMgt.XmlObjMgt_Persistent,theTarget : OCP.TDF.TDF_Attribute,theRelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: 
        """
        Reuses the base driver to read the base fields

        Reuses the base driver to store the base fields
        """
    @overload
    def Paste(self,theSource : OCP.TDF.TDF_Attribute,theTarget : OCP.XmlObjMgt.XmlObjMgt_Persistent,theRelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theDerivative : OCP.TDF.TDF_Attribute,theBaseDriver : XmlMDF_ADriver) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlMDF_ReferenceDriver(XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    """
    Attribute Driver.Attribute Driver.Attribute Driver.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.XmlObjMgt.XmlObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.XmlObjMgt.XmlObjMgt_Persistent,RelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlMDF_TagSourceDriver(XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    """
    Attribute Driver.Attribute Driver.Attribute Driver.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.XmlObjMgt.XmlObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.XmlObjMgt.XmlObjMgt_Persistent,RelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass



import OCP.SelectMgr.SelectMgr_MatOp
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.gp
import OCP.SelectMgr
__all__  = [
"Transform"
]
def Transform(theTrsf : OCP.gp.gp_Trsf,theVec : OCP.SelectMgr.SelectMgr_Vec3) -> OCP.SelectMgr.SelectMgr_Vec3:
    pass



import OCP.Geom2dEvaluator
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
import OCP.Geom2dAdaptor
import OCP.Geom2d
import OCP.gp
__all__  = [
"Geom2dEvaluator",
"Geom2dEvaluator_Curve",
"Geom2dEvaluator_OffsetCurve"
]
class Geom2dEvaluator():
    """
    The Geom2dEvaluator package provides utilities for . calculating value and derivatives of offset curve using corresponding values of base curve
    """
    @staticmethod
    def CalculateD0_s(theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theOffset : float) -> None: 
        """
        Recalculate D1 values of base curve into D0 value of offset curve
        """
    @staticmethod
    def CalculateD1_s(theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theD2 : OCP.gp.gp_Vec2d,theOffset : float) -> None: 
        """
        Recalculate D2 values of base curve into D1 values of offset curve
        """
    @staticmethod
    def CalculateD2_s(theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theD2 : OCP.gp.gp_Vec2d,theD3 : OCP.gp.gp_Vec2d,theIsDirChange : bool,theOffset : float) -> None: 
        """
        Recalculate D3 values of base curve into D2 values of offset curve
        """
    @staticmethod
    def CalculateD3_s(theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theD2 : OCP.gp.gp_Vec2d,theD3 : OCP.gp.gp_Vec2d,theD4 : OCP.gp.gp_Vec2d,theIsDirChange : bool,theOffset : float) -> None: 
        """
        Recalculate D3 values of base curve into D3 values of offset curve
        """
    def __init__(self) -> None: ...
    pass
class Geom2dEvaluator_Curve(OCP.Standard.Standard_Transient):
    """
    Interface for calculation of values and derivatives for different kinds of curves in 2D. Works both with adaptors and curves.Interface for calculation of values and derivatives for different kinds of curves in 2D. Works both with adaptors and curves.
    """
    def D0(self,theU : float,theValue : OCP.gp.gp_Pnt2d) -> None: 
        """
        Value of 2D curve
        """
    def D1(self,theU : float,theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d) -> None: 
        """
        Value and first derivatives of curve
        """
    def D2(self,theU : float,theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theD2 : OCP.gp.gp_Vec2d) -> None: 
        """
        Value, first and second derivatives of curve
        """
    def D3(self,theU : float,theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theD2 : OCP.gp.gp_Vec2d,theD3 : OCP.gp.gp_Vec2d) -> None: 
        """
        Value, first, second and third derivatives of curve
        """
    def DN(self,theU : float,theDerU : int) -> OCP.gp.gp_Vec2d: 
        """
        Calculates N-th derivatives of curve, where N = theDerU. Raises if N < 1
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def ShallowCopy(self) -> Geom2dEvaluator_Curve: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Geom2dEvaluator_OffsetCurve(Geom2dEvaluator_Curve, OCP.Standard.Standard_Transient):
    """
    Allows to calculate values and derivatives for offset curves in 2DAllows to calculate values and derivatives for offset curves in 2D
    """
    def D0(self,theU : float,theValue : OCP.gp.gp_Pnt2d) -> None: 
        """
        Value of curve
        """
    def D1(self,theU : float,theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d) -> None: 
        """
        Value and first derivatives of curve
        """
    def D2(self,theU : float,theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theD2 : OCP.gp.gp_Vec2d) -> None: 
        """
        Value, first and second derivatives of curve
        """
    def D3(self,theU : float,theValue : OCP.gp.gp_Pnt2d,theD1 : OCP.gp.gp_Vec2d,theD2 : OCP.gp.gp_Vec2d,theD3 : OCP.gp.gp_Vec2d) -> None: 
        """
        Value, first, second and third derivatives of curve
        """
    def DN(self,theU : float,theDeriv : int) -> OCP.gp.gp_Vec2d: 
        """
        Calculates N-th derivatives of curve, where N = theDeriv. Raises if N < 1
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def SetOffsetValue(self,theOffset : float) -> None: 
        """
        Change the offset value
        """
    def ShallowCopy(self) -> Geom2dEvaluator_Curve: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self,theBase : OCP.Geom2d.Geom2d_Curve,theOffset : float) -> None: ...
    @overload
    def __init__(self,theBase : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,theOffset : float) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
